Installable via pip.

Docs at http://venv_tools.rtfd.org.

.. image:: https://drone.io/bitbucket.org/aragilar/venv_tools/status.png
    :target: https://drone.io/bitbucket.org/aragilar/venv_tools/latest
